==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/KeyVaultPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property identity The client id of the identity which will be used to access key vault.
 * @property keyIdentifier Key vault uri to access the encryption key.
 */
public data class KeyVaultPropertiesArgs(
    public val identity: Output<String>? = null,
    public val keyIdentifier: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs.builder()
            .identity(identity?.applyValue({ args0 -> args0 }))
            .keyIdentifier(keyIdentifier?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultPropertiesArgs].
 */
@PulumiTagMarker
public class KeyVaultPropertiesArgsBuilder internal constructor() {
    private var identity: Output<String>? = null

    private var keyIdentifier: Output<String>? = null

    /**
     * @param value The client id of the identity which will be used to access key vault.
     */
    @JvmName("kqhpoppafdwepdio")
    public suspend fun identity(`value`: Output<String>) {
        this.identity = value
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("iuvkgbywbwkheqxh")
    public suspend fun keyIdentifier(`value`: Output<String>) {
        this.keyIdentifier = value
    }

    /**
     * @param value The client id of the identity which will be used to access key vault.
     */
    @JvmName("ylcqhveklckeivvk")
    public suspend fun identity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("tysapaougyqhdudl")
    public suspend fun keyIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyIdentifier = mapped
    }

    internal fun build(): KeyVaultPropertiesArgs = KeyVaultPropertiesArgs(
        identity = identity,
        keyIdentifier = keyIdentifier,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/KeyVaultPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property identity The client id of the identity which will be used to access key vault.
 * @property keyIdentifier Key vault uri to access the encryption key.
 */
public data class KeyVaultPropertiesArgs(
    public val identity: Output<String>? = null,
    public val keyIdentifier: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs =
        com.pulumi.azurenative.containerregistry.inputs.KeyVaultPropertiesArgs.builder()
            .identity(identity?.applyValue({ args0 -> args0 }))
            .keyIdentifier(keyIdentifier?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultPropertiesArgs].
 */
@PulumiTagMarker
public class KeyVaultPropertiesArgsBuilder internal constructor() {
    private var identity: Output<String>? = null

    private var keyIdentifier: Output<String>? = null

    /**
     * @param value The client id of the identity which will be used to access key vault.
     */
    @JvmName("yqnkogsbctjbmadu")
    public suspend fun identity(`value`: Output<String>) {
        this.identity = value
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("wophygqmcshoccut")
    public suspend fun keyIdentifier(`value`: Output<String>) {
        this.keyIdentifier = value
    }

    /**
     * @param value The client id of the identity which will be used to access key vault.
     */
    @JvmName("atahywieeyejgkes")
    public suspend fun identity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param value Key vault uri to access the encryption key.
     */
    @JvmName("wxacdeyluedhhypb")
    public suspend fun keyIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyIdentifier = mapped
    }

    internal fun build(): KeyVaultPropertiesArgs = KeyVaultPropertiesArgs(
        identity = identity,
        keyIdentifier = keyIdentifier,
    )
}
